# Django EVE Online Connector
Django module that supplies models, tasks, and fuctions for EVE Online. Primarily for use in the Krypted Platform. 

# Documentation
View documentation [here](https://kryptedgaming.github.io/django-eveonline-connector/).